@@ -24,14 +24,11 @@ fmt2len = {2: 1, 1794: 8, 3842: 16, 7938: 32, 12034: 48, 16130: 64, 18178: 72}
 
 typ_tab   = list(zip(*table))
 
+fmt2typ   = dict( zip(typ_tab[0], typ_tab[1]) )
 fmt2np    = dict( zip(typ_tab[0], typ_tab[2]) )
 fmt2ct    = dict( zip(typ_tab[0], typ_tab[3]) )
 fmt2struc = dict( zip(typ_tab[0], typ_tab[4]) )
 typ2np    = dict( zip(typ_tab[1], typ_tab[2]) )
-typ2ct    = dict( zip(typ_tab[1], typ_tab[3]) )
-fmt2typ   = dict( zip(typ_tab[0], typ_tab[1]) )
-for key in fmt2len.keys():
-    fmt2typ[key] = 6
 
 # /usr/ads/codes
 #  objects
