@@ -1,7 +1,7 @@
 import shutil, os, logging
 import ctypes as ct
 import numpy as np
-from aug_sfutils import sfdics, str_byt
+from aug_sfutils import sfdics, str_byt, sfread
 
 sfhlib = '/afs/ipp/aug/ads/lib64/amd64_sles11/libsfh8.so.20201118'
 libsfh = ct.cdll.LoadLibrary(sfhlib)
@@ -19,6 +19,7 @@ class SFH:
         self.c_sfid = ct.c_int32(0)
         _sfid = ct.byref(self.c_sfid)
 
+        self.sfhead = sfread.SFREAD(sfh=fname)
         err = libsfh.sfhopen(c_name, _sfid, len(fname))
         libsfh.sfherror(err, 'Open')
 
@@ -90,12 +91,17 @@ class SFH:
 
     def Modpar(self, ps, pn, dat):
 
-        parrec = self.Lparrec(ps)
-        par_dic = {}
+        pss = str_byt.to_str(ps)
+        pns = str_byt.to_str(pn)
+        if pss not in self.sf_head.parsets():
+            logger.debug('%s it not a parameter set', pss)
+            return
 
-        par_dic[pn] = {}
-        fmt = parrec[pn][0]
-        typ = sfdics.fmt2typ[fmt]
+        dfmt = self.sf_header(pss)[pn].data_format
+        if dfmt in sfdics.fmt2len.keys():
+            sf_dtype = 6
+        else:
+            sf_dtype = sfdics.fmt2typ[dfmt]
         pnlen = len(dat)
 # Input
         bps   = str_byt.to_byt(ps)
@@ -103,15 +109,15 @@ class SFH:
         bdat  = str_byt.to_byt(dat)
         c_ps  = ct.c_char_p(bps)
         c_pn  = ct.c_char_p(bpn)
-        c_typ = ct.c_uint32(typ)
+        c_typ = ct.c_uint32(sf_dtype)
         c_len = ct.c_uint32(pnlen)
         _typ  = ct.byref(c_typ)
         _len  = ct.byref(c_len)
 # Output
 
-        logger.debug('Modpar test: %s %d %d %d', pn, typ, pnlen, len(dat))
-        if fmt in sfdics.fmt2len.keys():
-            name_len = sfdics.fmt2len[fmt]
+        logger.debug('Modpar test: %s %d %d %d', pns, sf_dtype, pnlen, len(dat))
+        if dfmt in sfdics.fmt2len.keys():
+            name_len = sfdics.fmt2len[dfmt]
             c_len  = ct.c_uint32(pnlen)
             c_data = ct.c_char_p(bdat)
             err = libsfh.sfhmodpar(self.c_sfid, c_ps, c_pn, c_typ, c_len, c_data)
