@@ -8,7 +8,7 @@ PPGCLOCK = [1e-6, 1e-5, 1e-4, 1e-3]
 
 logger = logging.getLogger('aug_sfutils.sfread')
 date_fmt = '%Y-%m-%d'
-
+#logger.setLevel(logging.DEBUG)
 
 def read_other_sf(*args, **kwargs):
 
@@ -235,11 +235,10 @@ class SFREAD:
             self.objects = [ lbl for lbl in self.sfh['obj_nam'] if self.sfh[lbl].obj_type in [6, 7, 8, 13] ]
             self.parsets = [ lbl for lbl in self.sfh['obj_nam'] if self.sfh[lbl].obj_type in [3, 4] ]
         if 'ADDRLEN' in self.sfh.keys():
-            size_fac = sfdics.addrsizes[self.getaddrlen()]
+            size_fac = sfdics.addrsizes[self.sfh['ADDRLEN'].addrlen]
             for obj in self.sfh.keys():
                 if hasattr(self.sfh[obj], 'address'):
                     self.sfh[obj].address *= size_fac
-                    self.sfh[obj].length *= size_fac
         self.cache = {}
 
 
@@ -304,14 +303,6 @@ class SFREAD:
                     return self.getobject(rel)
         return None
 
-    def getaddrlen(self):
-
-        sfo = self.sfh['ADDRLEN']
-        data = unpack('>H', sfo.val[:2])[0]
-        logger.debug('getaddrlen addr:%d, len:%d, data:%d', sfo.address, sfo.length, data)
-        logger.debug(sfo.descr)
-        return data
-
     def getobject(self, obj, cal=False, nbeg=None, nend=None):
         """
         Reads the data of a given TB, AB, SIG or SGR
@@ -571,9 +562,6 @@ class SFREAD:
         ts6 = 0
         for obj in self.parsets:
             if self.sfh[obj].obj_type == 3:
-                logger.debug('getts06 Dev:%s n_chan:%d', obj, self.sfh[obj].n_chan)
-                if self.sfh[obj].n_chan > 1: # git ???
-                    break
                 ps = self.getparset(obj)
                 if 'TS06' in ps.keys():
                     ts6 = ps['TS06']
